import { useCallback, useEffect, useMemo, useState } from "react";
function throttle(fn) {
  let wait = false;
  return (...args) => {
    if (wait)
      return void 0;
    const result = fn(...args);
    wait = true;
    window.setTimeout(() => {
      wait = false;
    }, 200);
    return result;
  };
}
const usePillStyles = (ref, shouldTransform, dependencies) => {
  const [width, setWidth] = useState(0);
  const [distance, setDistance] = useState(0);
  const setStyles = useCallback(() => {
    if (ref.current && ref.current.parentElement) {
      setWidth(ref.current.clientWidth);
      const translateDistance = shouldTransform ? ref.current.parentElement.clientWidth - ref.current.clientWidth : 0;
      setDistance(translateDistance);
    }
  }, [ref, shouldTransform, ...dependencies]);
  const throttledSetStyles = useMemo(() => throttle(setStyles), [setStyles]);
  useEffect(() => {
    setStyles();
    typeof window !== "undefined" && window.addEventListener("resize", throttledSetStyles);
    return () => {
      typeof window !== "undefined" && window.removeEventListener("resize", throttledSetStyles);
    };
  }, [setStyles, throttledSetStyles]);
  return {
    width,
    transform: "translateX(".concat(distance, "px)")
  };
};
export {
  usePillStyles
};
//# sourceMappingURL=usePillStyles.js.map
